@@ -3,7 +3,7 @@ from rest_framework.exceptions import ValidationError
 
 from ...caluma_core.tests import extract_serializer_input_fields
 from ...caluma_form.models import DynamicOption, Question
-from .. import serializers, structure
+from .. import api, serializers, structure
 from ..jexl import QuestionMissing
 from ..validators import DocumentValidator, QuestionValidator
 
@@ -295,7 +295,7 @@ def test_validate_empty_answers(
 ):
 
     struct = structure.FieldSet(document, document.form)
-    field = struct.get_fields(question.slug)[0]
+    field = struct.get_field(question.slug)
     answer_value = field.value() if field else field
     assert answer_value == expected_value
 
@@ -747,3 +747,29 @@ def test_validate_form_in_table(
         # Should not raise, as the "form" referenced by the
         # question's jexl is the rowform, which is wrong
         DocumentValidator().validate(document, admin_user)
+
+
+@pytest.mark.parametrize("question__type", [Question.TYPE_CALCULATED_FLOAT])
+def test_validate_save_calculated_float_answer(db, document, question):
+    with pytest.raises(ValidationError):
+        api.save_answer(document=document, question=question, value=1.0)
+
+
+@pytest.mark.parametrize("question__type", [Question.TYPE_CALCULATED_FLOAT])
+def test_validate_save_calculated_float_question(db, document, question):
+
+    with pytest.raises(ValidationError):
+        QuestionValidator().validate(
+            data={
+                "type": Question.TYPE_CALCULATED_FLOAT,
+                "calc_expression": f"'{question.slug}'|answer",
+            }
+        )
+
+    with pytest.raises(ValidationError):
+        QuestionValidator().validate(
+            data={
+                "type": Question.TYPE_CALCULATED_FLOAT,
+                "calc_expression": "'foo'|answer",
+            }
+        )
